@@ -10,11 +10,10 @@ from typing import List, Optional
 
 import click
 import docker  # type: ignore
-from testcontainers.core.generic import DockerContainer  # type: ignore
 
 from pytezos import ContractInterface, __version__, pytezos
 from pytezos.cli.github import create_deployment, create_deployment_status
-from pytezos.context.mixin import default_network  # type: ignore
+from pytezos.context.mixin import default_network
 from pytezos.logging import DEFAULT_LOGGING_CONFIG, logger
 from pytezos.michelson.types.base import generate_pydoc
 from pytezos.operation.result import OperationResult
