@@ -159,7 +159,6 @@ class ImplicitAccountInstruction(MichelsonInstruction, prim='IMPLICIT_ACCOUNT'):
 
 
 class CreateContractInstruction(MichelsonInstruction, prim='CREATE_CONTRACT', args_len=1):
-
     @classmethod
     def execute(cls, stack: MichelsonStack, stdout: List[str], context: AbstractContext):
         sequence = cast(MichelineSequence, cls.args[0])
@@ -264,7 +263,6 @@ class LevelInstruction(MichelsonInstruction, prim='LEVEL'):
 
 
 class ViewInstruction(MichelsonInstruction, prim='VIEW', args_len=2):
-
     @classmethod
     def execute(cls, stack: 'MichelsonStack', stdout: List[str], context: AbstractContext):
         input_value, view_address = cast(Tuple[MichelsonType, AddressType], stack.pop2())
@@ -318,3 +316,13 @@ class OpenChestInstruction(MichelsonInstruction, prim='OPEN_CHEST'):
     @classmethod
     def execute(cls, stack: MichelsonStack, stdout: List[str], context: AbstractContext):
         raise NotImplementedError
+
+
+class MinBlockTimeInstruction(MichelsonInstruction, prim='MIN_BLOCK_TIME'):
+
+    @classmethod
+    def execute(cls, stack: MichelsonStack, stdout: List[str], context: AbstractContext):
+        res = NatType.from_value(context.get_min_block_time())
+        stack.push(res)
+        stdout.append(format_stdout(cls.prim, [], [res]))  # type: ignore
+        return cls(stack_items_added=1)
\ No newline at end of file
