@@ -3,14 +3,14 @@ from pytezos.michelson.types.big_map import BigMapType
 from pytezos.michelson.types.bls import BLS12_381_FrType, BLS12_381_G1Type, BLS12_381_G2Type
 from pytezos.michelson.types.chest import ChestKeyType, ChestType
 from pytezos.michelson.types.core import BoolType, BytesType, IntType, NatType, NeverType, StringType, UnitType
-from pytezos.michelson.types.domain import (AddressType, ChainIdType, ContractType, KeyHashType, KeyType, LambdaType, MutezType,
+from pytezos.michelson.types.domain import (AddressType, TXRAddress, ChainIdType, ContractType, KeyHashType, KeyType, LambdaType, MutezType,
                                             SignatureType, TimestampType)
 from pytezos.michelson.types.list import ListType
 from pytezos.michelson.types.map import MapType
 from pytezos.michelson.types.operation import OperationType
 from pytezos.michelson.types.option import OptionType
 from pytezos.michelson.types.pair import PairType
-from pytezos.michelson.types.sapling import SaplingStateType, SaplingTransactionType
+from pytezos.michelson.types.sapling import SaplingStateType, SaplingTransactionType, SaplingTransactionDeprecatedType
 from pytezos.michelson.types.set import SetType
 from pytezos.michelson.types.sum import OrType
 from pytezos.michelson.types.ticket import TicketType
