@@ -2,7 +2,7 @@ from decimal import Decimal
 from typing import Type, cast
 
 from pytezos.context.abstract import AbstractContext, get_originated_address
-from pytezos.crypto.encoding import base58_decode, is_address, is_chain_id, is_kt, is_pkh, is_public_key, is_sig
+from pytezos.crypto.encoding import base58_decode, is_address, is_chain_id, is_kt, is_txr_address, is_pkh, is_public_key, is_sig
 from pytezos.michelson.forge import (forge_address, forge_base58, forge_contract, forge_public_key, optimize_timestamp, unforge_address,
                                      unforge_chain_id, unforge_contract, unforge_public_key, unforge_signature)
 from pytezos.michelson.format import format_timestamp, micheline_to_michelson
@@ -121,6 +121,54 @@ class AddressType(StringType, prim='address'):
         return self.value
 
 
+class TXRAddress(StringType, prim='tx_rollup_l2_address'):
+
+    def __repr__(self):
+        return f'{self.value[:6]}…{self.value[-3:]}'
+
+    def __lt__(self, other: 'TXRAddress') -> bool:  # type: ignore
+        if is_kt(other.value):
+            return True
+        elif is_pkh(other.value):
+            return False
+        else:
+            return self.value < other.value
+
+    @classmethod
+    def dummy(cls, context: AbstractContext) -> 'TXRAddress':
+        return cls.from_value(context.get_dummy_txr_address())
+
+    @classmethod
+    def from_value(cls, value: str) -> 'TXRAddress':
+        if value.endswith('%default'):
+            value = value.split('%')[0]
+        assert is_txr_address(value), f'expected txr1 address, got {value}'
+        return cls(value)
+
+    @classmethod
+    def from_micheline_value(cls, val_expr) -> 'TXRAddress':
+        value = parse_micheline_literal(val_expr, {
+            'bytes': lambda x: unforge_contract(bytes.fromhex(x)),
+            'string': lambda x: x
+        })
+        return cls.from_value(value)
+
+    @classmethod
+    def from_python_object(cls, py_obj) -> 'TXRAddress':
+        return cls.from_value(py_obj)
+
+    def to_micheline_value(self, mode='readable', lazy_diff=False):
+        if mode in ['optimized', 'legacy_optimized']:
+            return {'bytes': forge_contract(self.value).hex()}  # because address can also have an entrypoint
+        elif mode == 'readable':
+            return {'string': self.value}
+        else:
+            assert False, f'unsupported mode {mode}'
+
+    def to_python_object(self, try_unpack=False, lazy_diff=False, comparable=False):
+        return self.value
+
+
 class KeyType(StringType, prim='key'):
 
     @property
